@@ -1,4 +1,7 @@
-#! /usr/local/bin/perl -ws
+#! /opt/local/bin/perl5.10.0
+use v5.10;
+use warnings;
+
 
 use Parse::RecDescent;
 
